
{*****************************************************************************}
{ TGameInfo v1.0                                                              }
{*****************************************************************************}
{ This component was developed to retrieve systeminformation of special interest
 to gameprogrammers. It was developed for Delphi 4. However, I believe that it
 should be possible to use the component with earlier versions of Delphi.

 This Freeware component was developed by:

      Henrik Fabricius, 1999.
      E-mail : henrik_og_bodil@vip.cybercity.dk

 The latest version of this component is available at:

      http://users.cybercity.dk/~bbl6194/Delphi3DX
                                                                              }
{*****************************************************************************}
{Date last modified:  February 9th 1999                                       }
{*****************************************************************************}


unit GameInfo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ShellAPI, Registry;

type
  TGameInfo = class(TComponent)
  private
    { Private declarations }
    FComputerName: String;
    FUserName: String;
    FWinDir: String;
    FSysDir: String;
    FRegOwner: String;
    FRegCompany: String;
    FVersion: String;
    FPlatform: String;
    FPlatformID: DWord;
    FDispResu: string;
    FDirectXvs: string;
    FBitsPixel: string;
    FCPUvendor: string;

    function myGetSystemInfoDWORD( const Index : Integer ) : DWORD;
    function myGlobalMemoryStatus( const Index : Integer):DWORD;

  protected
    { Protected declarations }
    constructor Create(AOwner: TComponent); override;
    procedure GetComputer;
    procedure GetUser;
    procedure GetDirectories;
    procedure GetRegInfo;
    procedure GetOSVersion;
  public
    { Public declarations }
  published
    { Published declarations }

    property ComputerName: String read FComputerName;
    property UserName: String read FUserName;
    property WinDir: String read FWinDir;
    property SysDir: String read FSysDir;
    property RegOwner: String read FRegOwner;
    property RegCompany: String read FRegCompany;
    property OSVersion: String read FVersion;
    property OSPlatform: String read FPlatform;
    property DispResu: String read FDispResu;
    property DirectXvs: String read FDirectXvs;
    property BitsPixel: string read FBitsPixel;
    property CPUvendor: string read FCPUvendor;
    //From GlobalMemoryStatus
    property dwMemoryLoad : DWORD index 1 read myGlobalMemoryStatus;
    property dwTotalPhys : DWORD index 2 read myGlobalMemoryStatus;
    property dwAvailPhys : DWORD index 3 read myGlobalMemoryStatus;
    property dwTotalPageFile : DWORD index 4 read myGlobalMemoryStatus;
    property dwAvailPageFile : DWORD index 5 read myGlobalMemoryStatus;
    property dwTotalVirtual : DWORD index 6 read myGlobalMemoryStatus;
    property dwAvailVirtual : DWORD index 7 read myGlobalMemoryStatus;
    //TsystemInfo
    //Word Fields
    property PageSize : DWORD index 1 read myGetSystemInfoDWORD;
    property ActiveProcessorMask : DWORD index 2 read myGetSystemInfoDWORD;
    property NumberOfProcessors : DWORD index 3 read myGetSystemInfoDWORD;
    property ProcessorType : DWORD index 4 read myGetSystemInfoDWORD;
    property AllocationGranularity :DWORD index 5 read myGetSystemInfoDWORD;

  end;

procedure Register;

const
  PROCESSOR_INTEL_386 = 386;
  PROCESSOR_INTEL_486 = 486;
  PROCESSOR_INTEL_PENTIUM = 586;


implementation

procedure Register;
begin
  RegisterComponents('Samples', [TGameInfo]);
end;

constructor TGameInfo.Create(AOwner: TComponent);
begin
   inherited;
   //get details
   GetComputer;
   GetUser;
   GetDirectories;
   GetOSVersion;
   GetRegInfo;     //getosversion must be called before getreginfo

end;



function TgameInfo.myGetSystemInfoDWORD( const Index : Integer ) : DWORD;
var
  SysInfo : TSystemInfo;
begin

  Windows.GetSystemInfo( SysInfo );

  with SysInfo do
  case Index of
  1 : Result := dwPageSize;
  2 : Result := dwActiveProcessorMask;
  3 : Result := dwNumberOfProcessors;
  4 : Result := dwProcessorType;
  5 : Result := dwAllocationGranularity;
  else Result := null;
  end; // case index of
end;





function TGameInfo.myGlobalMemoryStatus( const Index : Integer): DWORD;
var
  MemoryStatus : TMemoryStatus;
begin
  with MemoryStatus do
  begin
    dwLength := SizeOf( TMemoryStatus );
    Windows.GlobalMemoryStatus( MemoryStatus );
    case Index of
    1 : Result := dwMemoryLoad;
    2 : Result := dwTotalPhys div 1024;
    3 : Result := dwAvailPhys div 1024;
    4 : Result := dwTotalPageFile div 1024;
    5 : Result := dwAvailPageFile div 1024;
    6 : Result := dwTotalVirtual div 1024;
    7 : Result := dwAvailVirtual div 1024;
    else Result := 0;
    end; //Case
  end; // with MemoryStatus
end;






procedure TGameInfo.GetComputer;
var
   ComputerName : PChar;
   NameSize : DWORD;
begin
   ComputerName := #0;
   NameSize := MAX_COMPUTERNAME_LENGTH + 1;
   try
      GetMem(ComputerName, NameSize);
      Windows.GetComputerName(ComputerName, NameSize);
      FComputerName:= StrPas(ComputerName);
   finally
      FreeMem(ComputerName);
   end;
end;

procedure TGameInfo.GetUser;
var
   UserName : PChar;
   NameSize : DWORD;
begin
   UserName := #0;
   NameSize := 50;
   try
      GetMem(UserName, NameSize);
      Windows.GetUserName(UserName, NameSize);
      FUserName:= StrPas(UserName);
   finally
      FreeMem(UserName);
   end;
end;

procedure TGameInfo.GetDirectories;
var
    Size: integer;
    Names: Pchar;
begin
  Names := #0;
  try
    GetMem( Names, MAX_PATH+1 );

    Size := GetSystemDirectory(Names, MAX_PATH+1);
    FSysDir := StrPas(Names);

    Size := GetWindowsDirectory(Names, MAX_PATH+1);
    FWinDir := StrPas(Names);

  finally
    FreeMem( Names );
  end; //of try
end;

procedure TGameInfo.GetRegInfo;
const
  WIN95_KEY = '\SOFTWARE\Microsoft\Windows\CurrentVersion';
  WINNT_KEY = '\SOFTWARE\Microsoft\Windows NT\CurrentVersion';
  DX_KEY = '\SOFTWARE\Microsoft\DirectX';
  MONI_KEY = 'Display\Settings';
  CPU_KEY = '\hardware\DESCRIPTION\System\CentralProcessor\0';
var
  VersionKey: PChar;

begin
   //get platform id details
   //note platform id is set by getosversion - so getosversion should already have been called
   case FPlatformID of
      VER_PLATFORM_WIN32_WINDOWS:  VersionKey := WIN95_KEY;
      VER_PLATFORM_WIN32_NT     :  VersionKey := WINNT_KEY;
      else  VersionKey := nil;
   end;

   with TRegistry.Create do
   try
       RootKey := HKEY_LOCAL_MACHINE;

       if OpenKey(VersionKey, False) then
          begin
          FRegOwner := ReadString('RegisteredOwner');
          FRegCompany := ReadString('RegisteredOrganization');
          end;

       {jeg nsker endvidere}
       if OpenKey(DX_KEY, False) then
          begin
            FDirectXvs:= Readstring('Version');
          end;

       if OpenKey(CPU_KEY, False) then
          begin
            FCPUvendor:= ReadString('VendorIdentifier');
          end;

       RootKey := HKEY_CURRENT_CONFIG;

       if OpenKey(MONI_KEY, False) then
          begin
            FDispResu := ReadString('Resolution');
            FBitsPixel := ReadString('BitsPerPixel');
          end;



   finally
     Free;
   end; // of try

end;




procedure TGameInfo.GetOSVersion;
var
  OSVersion: TOSVersionInfo;
begin
   OSVersion.dwOSVersionInfoSize := SizeOf(OSVersion);

   if GetVersionEx(OSVersion) then
      begin
         FVersion := Format('%d.%d (%d.%s)',[OSVersion.dwMajorVersion, OSVersion.dwMinorVersion,(OSVersion.dwBuildNumber and $FFFF), OSVersion.szCSDVersion]);
         FPlatformID:= OSVersion.dwPlatformID;
         case OSVersion.dwPlatformID of
            VER_PLATFORM_WIN32s:        FPlatform := 'Windows 3.1';
            VER_PLATFORM_WIN32_WINDOWS: FPlatform := 'Windows 95';
            VER_PLATFORM_WIN32_NT:      FPlatform := 'Windows NT';
            else                        FPlatform := '';
         end;  //of case
      end; //of if
end;




end.
